//
//  MFSettingCell.m
//  TableViewFull
//
//  Created by SunLi on 16/4/21.
//  Copyright © 2016年 lb. All rights reserved.
//

#import "MFSettingCell.h"

#import "MFSettingCellItem.h"
#import "MFSettingArrowItem.h"
#import "MFSettingSwitchItem.h"
#import "MFSettingLabelItem.h"
#import "MFSettingLabelArrowItem.h"
#import "MFSettingIconItem.h"
#import "MFSettingButtonItem.h"
#import "MFLabelArrowView.h"
#import "MFSettingIconArrowItem.h"
#import "MFIconArrowView.h"
#import "CommonHelper.h"
#import "IPhoneScreen.h"


// view背景颜色
#define MFViewBackgroundColor CFColor(244, 243, 241)

// Cell上右边Label文字颜色
#define MFRightLabelTextColor [CommonHelper hexColor:@"#a2a2a3"]

// Cell上文字颜色
#define MFCellTextColor [CommonHelper hexColor:@"#5e5e5e"]

@interface MFSettingCell ()
//左边图片视图
@property(nonatomic, strong) UIImageView *imgView;
//switch视图
@property(nonatomic, strong) UISwitch *switchView;
//Label
@property(nonatomic, strong) UILabel *labelView;
//文本箭头
@property(nonatomic, strong) MFLabelArrowView *labelArrowView;
//图标箭头
@property(nonatomic, strong) MFIconArrowView *iconArrowView;
//头部视图
@property(nonatomic, strong) UIButton *headView;
//分隔视图
@property(nonatomic, weak) UIView *divider;

@end

@implementation MFSettingCell

- (UIView *)divider {
    if (_divider == nil) {
        if ([IPhoneScreen version]< 7.0f) { // 不是ios7以后才需要创建分割线
            UIView *divider = [[UIView alloc] init];
            divider.backgroundColor = [UIColor blackColor];
            divider.alpha = 0.2;
            
            [self.contentView addSubview:divider];
            _divider = divider;
        }
    }
    
    return _divider;
}

- (UILabel *)labelView {
    if (_labelView == nil) {
        _labelView = [[UILabel alloc] init];
        _labelView.bounds = CGRectMake(0, 0, self.frame.size.width * 0.55, self.frame.size.height);
    }
    return _labelView;
}

- (UIImageView *)imgView {
    if (_imgView == nil) {
        if(self.iconArrow.length > 0){
            _imgView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:self.iconArrow]];
        }
        else{
            return nil;
        }
    }
    return _imgView;
}

- (UIButton *)headView {
    if (_headView == nil) {
        _headView = [[UIButton alloc] init];
        _headView.userInteractionEnabled = NO;
        _headView.frame = CGRectMake(0, 0, 80, 80);
    }
    return _headView;
}

//Label&箭头
- (MFLabelArrowView *)labelArrowView {
    if (_labelArrowView == nil) {
        _labelArrowView = [[MFLabelArrowView alloc] init];
        _labelArrowView.iconArrow = self.iconArrow;
        _labelArrowView.bounds = CGRectMake(0, 0, self.frame.size.width * 0.55, self.frame.size.height);
    }
    return _labelArrowView;
}
//图标&箭头
- (MFIconArrowView *)iconArrowView {
    if (_iconArrowView == nil) {
        _iconArrowView = [[MFIconArrowView alloc] init];
        _iconArrowView.iconArrow = self.iconArrow;
        _iconArrowView.bounds = CGRectMake(0, 0, self.frame.size.width * 0.55, self.frame.size.height);
    }
    return _iconArrowView;
}

//Switch视图
- (UISwitch *)switchView {
    if (_switchView == nil) {
        _switchView = [[UISwitch alloc] init];
    }
    return _switchView;
}

- (void)setItem:(MFSettingCellItem *)item {
    _item = item;
    
    // 设置cell的子控件的数据
    [self setUpData];
    
    // 设置右边视图
    [self setUpAccessoryView];
}

/**
 *  设置cell的子控件的数据
 */
- (void)setUpData {

    if (_item.icon != nil && _item.icon.length) {
        self.imageView.image = [UIImage imageNamed:_item.icon];
    } else {
        self.imageView.image = nil;
    }
    self.textLabel.text = _item.title;
    self.detailTextLabel.text = _item.subTitle;
}

/**
 *  设置右边视图分类
 */
- (void)setUpAccessoryView {
    if ([_item isKindOfClass:[MFSettingArrowItem class]]) { // Cell右边箭头
        MFSettingArrowItem *arrowItem = (MFSettingArrowItem*)_item;
        if (arrowItem.displayArrowIcon == YES)
            self.accessoryView = nil;  //默认存在视图
        else
            self.accessoryView = self.imgView;
        self.selectionStyle = UITableViewCellSelectionStyleDefault;
        
    } else if ([_item isKindOfClass:[MFSettingSwitchItem class]]) { // Cell右边Switch
        self.accessoryView = self.switchView;
   
        [self.switchView addTarget:self action:@selector(switchValueChanged:) forControlEvents:UIControlEventValueChanged];
        self.selectionStyle = UITableViewCellSelectionStyleNone;
    }
    else if ([_item isKindOfClass:[MFSettingLabelItem class]]) { // Cell右边Label
        self.accessoryView = self.labelView;
        MFSettingLabelItem *labelItem = (MFSettingLabelItem *)_item;
        self.labelView.text = labelItem.text_right;
        self.labelView.textColor = MFRightLabelTextColor;
        self.labelView.font = [UIFont systemFontOfSize:15];
        self.labelView.textAlignment = NSTextAlignmentRight;
        self.selectionStyle = UITableViewCellSelectionStyleNone;
    }
    else if ([_item isKindOfClass: [MFSettingLabelArrowItem class]]) { // Cell右边Label和Arrow
        self.accessoryView = self.labelArrowView;
        MFSettingLabelArrowItem *labelarrowItem = (MFSettingLabelArrowItem *)_item;
        self.labelArrowView.text = labelarrowItem.text_right;
        self.selectionStyle = UITableViewCellSelectionStyleDefault;
    }
    else if ([_item isKindOfClass:[MFSettingIconItem class]]) { //Cell右边是图片
        self.accessoryView = self.headView;  //设置方向为图片
        MFSettingIconItem *iconItem = (MFSettingIconItem *)_item;
        [self.headView setImage:[UIImage imageNamed:iconItem.icon_right] forState:UIControlStateNormal];
        self.selectionStyle = iconItem.cellSelectionStyle;
    }
    else if ([_item isKindOfClass: [MFSettingIconArrowItem class]]) { //Cell右边有图片和箭头
        self.accessoryView = self.iconArrowView;
        MFSettingIconArrowItem *iconArrowItem = (MFSettingIconArrowItem *)_item;
        self.iconArrowView.icon_right = iconArrowItem.icon_right;
        self.selectionStyle = iconArrowItem.cellSelectionStyle;
    }else if ([_item isKindOfClass:[MFSettingButtonItem class]]){
        self.accessoryView = nil;
        self.textLabel.text = @"";  //去除自身的Title
        MFSettingButtonItem *btnItem = (MFSettingButtonItem *)_item;
        UIButton *btn = [UIButton buttonWithType:UIButtonTypeCustom];

        [btn setTitle:btnItem.title forState:UIControlStateNormal];
        [btn setTitleColor:[UIColor orangeColor] forState:UIControlStateNormal];
        btn.titleLabel.font = [UIFont systemFontOfSize:16.0f];
        [btn setContentHorizontalAlignment:UIControlContentHorizontalAlignmentCenter];
        btn.frame = self.bounds;  //铺满
        [self addSubview:btn];
        //事件
        [btn addTarget:self action:@selector(cellButtonClick:) forControlEvents:UIControlEventTouchUpInside];
    }
    else {
        self.accessoryView = nil;
        self.selectionStyle = UITableViewCellSelectionStyleDefault;
    }
}

#pragma mark 事件处理
/*
 * switch的切换
 */
-(void)switchValueChanged:(UISwitch *)switchControl{
    NSLog(@"switchValueChanged %d",switchControl.isOn);
 
    if ([_item isKindOfClass:[MFSettingSwitchItem class]]) { // Cell右边Switch
        MFSettingSwitchItem *switchItem = (MFSettingSwitchItem *)_item;
        //保存uniqueId
        if ([CommonHelper isNotEmptyAndNull:switchItem.uniqueId]){
           // [CoreArchive setBool:switchControl.isOn key:switchItem.uniqueId];
        }
        //block
        if(switchItem.opration_switch){
            switchItem.opration_switch(switchControl.isOn);
        }
    }
}

/*
 * 退出事件处理
 */
-(void)cellButtonClick:(UIButton *)button
{
    NSLog(@"cellButtonClick %@",button.titleLabel.text);
    if ([_item isKindOfClass:[MFSettingButtonItem class]]){
        MFSettingButtonItem *btnItem = (MFSettingButtonItem *)_item;
        if (btnItem.cellBtnOperate){
            btnItem.cellBtnOperate(@"logout");
        }
    }
}

/**
 *  快速创建cell
 */
+ (instancetype)cellWithTableView:(UITableView *)tableView{
    static NSString *identifier = @"CFSettingCell";
    MFSettingCell *cell = [tableView dequeueReusableCellWithIdentifier:identifier];
    
    if (cell == nil) {
        cell = [[MFSettingCell alloc] initWithStyle:UITableViewCellStyleValue1 reuseIdentifier:identifier];
        cell.textLabel.textColor = MFCellTextColor;
        cell.textLabel.font = [UIFont boldSystemFontOfSize:17];
    }
 
    return cell;
}

/**
 *  判断分割线是否需要显示
 */
- (void)setIndexPath:(NSIndexPath *)indexPath {
    _indexPath = indexPath;
    
    self.divider.hidden = indexPath.row == 0;
}

/** 
 * 样式初始化cell
 */
- (id)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier {
    if (self = [super initWithStyle:style reuseIdentifier:reuseIdentifier]) {
        // 清空子视图的背景
        [self setSubViews];
    }
    
    return self;
}

/**
 *  清空子控件的背景颜色
 */
- (void)setSubViews {
    self.textLabel.backgroundColor = [UIColor clearColor];
    self.detailTextLabel.backgroundColor = [UIColor clearColor];
}

/**
 * 适配ios6的cell
 */
- (void)setFrame:(CGRect)frame {
    if ([IPhoneScreen version] < 7.0) { //
        frame.size.width += 20;
        frame.origin.x -= 10;
    }
    
    [super setFrame:frame];
}

/**
 *  cell箭头
 */
-(void)setIconArrow:(NSString *)iconArrow{
    _iconArrow = iconArrow;
}

/**
 *  cell右边Label字体
 */
-(void)setRightLabelFont:(UIFont *)rightLabelFont{
    _rightLabelFont = rightLabelFont;
    self.labelView.font = rightLabelFont;
    self.labelArrowView.rightLabelFont = rightLabelFont;
}

/**
 *  cell右边Label字体颜色
 */
-(void)setRightLabelFontColor:(UIColor *)rightLabelFontColor{
    _rightLabelFontColor = rightLabelFontColor;
    self.labelView.textColor = rightLabelFontColor;
    self.labelArrowView.rightLabelFontColor = rightLabelFontColor;
}

/**
 *  设置背景颜色
 */
-(void)setBackgroundColor_Normal:(UIColor *)backgroundColor_Normal{
    _backgroundColor_Normal = backgroundColor_Normal;
    
    UIView *bg = [[UIView alloc] init];
    bg.backgroundColor = backgroundColor_Normal;
    self.backgroundView = bg;
}

/**
 *  设置选中的背景颜色
 */
-(void)setBackgroundColor_Selected:(UIColor *)backgroundColor_Selected{
    _backgroundColor_Selected = backgroundColor_Selected;
    
    UIView *selectedBg = [[UIView alloc] init];
    selectedBg.backgroundColor = backgroundColor_Selected;
    self.selectedBackgroundView = selectedBg;
}

/**
 *  设置分割线的frame
 */
- (void)layoutSubviews {
    [super layoutSubviews];
    
    CGFloat dividerX = self.textLabel.frame.origin.x;
    CGFloat dividerY = 0;
    CGFloat dividerH = 1;
    CGFloat dividerW = self.frame.size.width;
    self.divider.frame = CGRectMake(dividerX, dividerY, dividerW, dividerH);
}
@end
