//
//  CFSettingTableViewController.m
//  TableViewSettingList
//
//  Created by wangchangfei on 15/9/24.
//  Copyright (c) 2015年 wangchangfei. All rights reserved.
//

#import "MFSettingTableViewController.h"
#import "MFSettingCell.h"
#import "MFSettingCellItem.h"
#import "MFSettingArrowItem.h"
#import "MFSettingSwitchItem.h"
#import "MFSettingLabelArrowItem.h"
#import "MFSettingIconArrowItem.h"
#import "MFSettingGroup.h"
#import "CommonHelper.h"
#import "IPhoneScreen.h"


const CGFloat sectionHeight = 10;

@interface MFSettingTableViewController ()

@end

@implementation MFSettingTableViewController

- (NSMutableArray *)dataList {
    if (_dataList == nil) {
        _dataList = [NSMutableArray array];
    }
    return _dataList;
}

// 利用组(group)初始化方法
- (instancetype)init {
    return [super initWithStyle:UITableViewStyleGrouped];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    // 设置tableView的背景颜色
    self.tableView.backgroundView = nil;
    self.tableView.backgroundColor = [CommonHelper rgb:244 andg:243 andb:241]; // CFViewBackgroundColor;
    
    // 适配iOS7的组间距
    if ([IPhoneScreen version] >=7.0) {
        self.tableView.contentInset = UIEdgeInsetsMake(0, 0, 0, 0);
    }
}

#pragma mark - Table view data source
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return self.dataList.count;
}

//分组
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    MFSettingGroup *group = self.dataList[section];
    return group.items.count;
}

//初始化相关信息
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    // 创建cell
    MFSettingCell *cell = [[MFSettingCell class] cellWithTableView:tableView];
    
    // 设置参数
    cell.backgroundColor_Normal = self.backgroundColor_Normal;
    cell.backgroundColor_Selected = self.backgroundColor_Selected;
    cell.iconArrow = self.icon_arrow;
    cell.rightLabelFont = self.rightLabelFont;
    cell.rightLabelFontColor = self.rightLabelFontColor;
    
    // 取出模型
    MFSettingGroup *group = self.dataList[indexPath.section];
    MFSettingCellItem  *item = group.items[indexPath.row];
    
    // 传递模型
    cell.item = item;
    cell.indexPath = indexPath;
    return cell;
}

#pragma mark - UITableViewDelegate

- (CGFloat) tableView:(UITableView *)tableView heightForRowAtIndexPath :(NSIndexPath *)indexPath {
    MFSettingGroup *group = self.dataList[indexPath.section];
    MFSettingCellItem  *item = group.items[indexPath.row];
    return item.cellHeight > 0 ? item.cellHeight : 44;
}

- (CGFloat) tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    MFSettingGroup *group = self.dataList[section];
    if(group.headerHeight > 0){
        return group.headerHeight;
    }
    else {
        if (section == 0) {
            return sectionHeight * 2;
        } else {
            return sectionHeight;
        }
    }
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
    MFSettingGroup *group = self.dataList[section];
    if(group.footerHeight > 0){
        return group.footerHeight;
    }
    else {
        return sectionHeight;
    }
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    MFSettingGroup *group = self.dataList[section];
    return group.header;
}

- (NSString *)tableView:(UITableView *)tableView titleForFooterInSection:(NSInteger)section {
    MFSettingGroup *group = self.dataList[section];
    return group.footer;
}

- (UIView *)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section {
    MFSettingGroup *group = self.dataList[section];
    return group.headerView;
}

- (UIView *)tableView:(UITableView *)tableView viewForFooterInSection:(NSInteger)section {
    MFSettingGroup *group = self.dataList[section];
    return group.footerrView;
}

/**
 *  点击某一行cell
 */
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    // 取消选中
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    
    // 取出模型
    MFSettingGroup *group = self.dataList[indexPath.section];
    MFSettingCellItem  *item = group.items[indexPath.row];
    
    // 执行操作
    if (item.opration) {
        item.opration();
        return;
    }
    
    if ([item isKindOfClass:[MFSettingArrowItem class]]) { // 需要跳转控制器
        MFSettingArrowItem *arrowItem = (MFSettingArrowItem *)item;
        
        // 创建跳转的控制器
        if (arrowItem.destVcClass) {
            UIViewController *vc = [[arrowItem.destVcClass alloc] init];
            vc.title = item.title;
            [vc setModalTransitionStyle:UIModalTransitionStyleFlipHorizontal];
            [vc setModalPresentationStyle:UIModalPresentationFormSheet];
            [self hidenTabBar:vc];
        }
    }
    else if ([item isKindOfClass:[MFSettingLabelArrowItem class]]) { // 需要跳转控制器
        MFSettingLabelArrowItem *arrowItem = (MFSettingLabelArrowItem *)item;
        
        // 创建跳转的控制器
        if (arrowItem.destVcClass) {
            UIViewController *vc = [[arrowItem.destVcClass alloc] init];
            vc.title = item.title;
            [vc setModalTransitionStyle:UIModalTransitionStyleFlipHorizontal];
            [vc setModalPresentationStyle:UIModalPresentationCurrentContext];
            [self hidenTabBar:vc];
        }
    }
    else if ([item isKindOfClass:[MFSettingIconArrowItem class]]) { // 需要跳转控制器
        MFSettingIconArrowItem *iconArrowItem = (MFSettingIconArrowItem *)item;
        
        // 创建跳转的控制器
        if (iconArrowItem.destVcClass) {
            UIViewController *vc = [[iconArrowItem.destVcClass alloc] init];
            vc.title = item.title;
            [vc setModalTransitionStyle:UIModalTransitionStyleFlipHorizontal];
            [vc setModalPresentationStyle:UIModalPresentationPageSheet];
            [self hidenTabBar:vc];
        }
    }
}

//设置是否隐藏tabBar
- (void)hidenTabBar:(UIViewController *)controller
{
    //隐藏tabbar
    self.tabBarController.tabBar.hidden = YES;
    self.hidesBottomBarWhenPushed = YES;
    [self.navigationController pushViewController:controller animated:YES];
    self.hidesBottomBarWhenPushed = NO;  //显示tabbar
}

@end